@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -47,7 +47,7 @@ public:
         : q(qq)
     {
         QVBoxLayout *lay = new QVBoxLayout(q);
-        lay->setMargin(0);
+        lay->setContentsMargins(0, 0, 0, 0);
         QHBoxLayout *hbox = new QHBoxLayout;
         QLabel *lab = new QLabel(i18n("Image Location:"));
         imageUrlRequester = new KUrlRequester;
